@@ -22,6 +22,10 @@ def check_type(actual, definition):
     if type(definition) == typing.TypeVar:
         return True
 
+    # Any allows any.
+    if definition == typing.Any:
+        return True
+
     # Currently support list, set, dict and union
     if hasattr(definition, "__origin__"):
         if hasattr(actual, "__origin__"):
@@ -31,4 +35,7 @@ def check_type(actual, definition):
             )
         return any(check_type(actual, arg) for arg in definition.__args__)
 
-    return actual == definition
+    try:
+        return issubclass(actual, definition)
+    except TypeError:
+        return actual == definition
